@@ -87,7 +87,6 @@ func CmdName() string {
 }
 
 func main() {
-	forcedIfchange := flag.Bool("f", false, "forced redo-ifchange")
 	version := flag.Bool("version", false, "print version")
 	warranty := flag.Bool("warranty", false, "print warranty information")
 
@@ -336,7 +335,7 @@ CmdSwitch:
 			}
 		}
 	case CmdNameRedoIfchange:
-		ok, err = ifchange(tgts, *forcedIfchange, traced)
+		ok, err = ifchange(tgts, *flagForcedIfchange, traced)
 		if err == nil {
 			err = depsWrite(fdDep, tgts)
 		}
