@@ -69,10 +69,11 @@ var (
 	StopIfMod    = false
 	Jobs         sync.WaitGroup
 
-	flagTrace        *bool
-	flagTraceAll     *bool
-	flagStderrKeep   *bool
-	flagStderrSilent *bool
+	flagTrace          *bool
+	flagTraceAll       *bool
+	flagStderrKeep     *bool
+	flagStderrSilent   *bool
+	flagForcedIfchange *bool
 
 	TracedAll bool
 
@@ -94,6 +95,7 @@ func init() {
 		fmt.Sprintf("keep job's stderr (%s=1)", EnvStderrKeep))
 	flagStderrSilent = flag.Bool("s", false,
 		fmt.Sprintf("silent, do not print job's stderr (%s=1)", EnvStderrSilent))
+	flagForcedIfchange = flag.Bool("f", false, "forced redo-ifchange")
 }
 
 type RunError struct {
